summaryrefslogtreecommitdiff
path: root/enablesanitizers.sh
diff options
context:
space:
mode:
authorKonstantin Baladurin <k.baladurin@partner.samsung.com>2018-01-26 01:19:19 +0300
committerJan Vorlicek <janvorli@microsoft.com>2018-01-25 23:19:19 +0100
commit9639f454de21775ab1031471c2acb64738b77c95 (patch)
treedbbe9db41865ddee216ec447dec6f4238eab8a26 /enablesanitizers.sh
parent209415618ca5d1a5d1d9e39ca78d643d0935534e (diff)
downloadcoreclr-9639f454de21775ab1031471c2acb64738b77c95.tar.gz
coreclr-9639f454de21775ab1031471c2acb64738b77c95.tar.bz2
coreclr-9639f454de21775ab1031471c2acb64738b77c95.zip
Fix asan false-positive errors: (#15563)
- Call __asan_handle_no_return in RtlRestoreContext if it doesn't return and in ThrowExceptionFromContextInternal function; - Increase alternate signal stack size and use it also for asan.
Diffstat (limited to 'enablesanitizers.sh')
-rwxr-xr-xenablesanitizers.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/enablesanitizers.sh b/enablesanitizers.sh
index 2937b0b2f4..aedb95d0d6 100755
--- a/enablesanitizers.sh
+++ b/enablesanitizers.sh
@@ -83,8 +83,9 @@ else
unset DEBUG_SANITIZERS
echo "Setting DEBUG_SANITIZERS="
else
- # for now, specify alloc_dealloc_mismatch=0 as there are too many error reports that are not an issue
- ASAN_OPTIONS="symbolize=1 alloc_dealloc_mismatch=0"
+ # for now, specify alloc_dealloc_mismatch=0 as there are too many error reports that are not an issue.
+ # Also specify use_sigaltstack=0 as coreclr uses own alternate stack for signal handlers
+ ASAN_OPTIONS="symbolize=1 alloc_dealloc_mismatch=0 use_sigaltstack=0"
# when Clang 3.8 available, add: suppressions=$(readlink -f sanitizersuppressions.txt)
UBSAN_OPTIONS="print_stacktrace=1"
@@ -132,4 +133,4 @@ else
unset __EnableLSan
unset __TurnOff
unset __Options
-fi \ No newline at end of file
+fi